Welcome to the Octavia Proxy API
================================

This project translates Octavia API requests into elbv2 and elbv3 of the Open
Telekom Cloud. It is required due to missing possibility to implement elbv3
support as a native Octavia driver (it doesn't offer admin type of access and
to have primary data source in Octavia).


.. toctree::
   :maxdepth: 1

   admin/index
   reference/index
   configuration/index
   contributor/index
   install/index
   user/index
